==> haskell-conversion-bytestring-1.0.1-18-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conversion-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 conversion-bytestring
version:              1.0.1
visibility:           public
id:                   conversion-bytestring-1.0.1-h5IWBGzHid7H9R6NI1Axd
key:                  conversion-bytestring-1.0.1-h5IWBGzHid7H9R6NI1Axd
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/conversion-bytestring 
synopsis:             "Conversion" instances for the "bytestring" library
category:             Control, Data, Conversion
abi:                  ff6f317c472a48a75e2cede6ff90a117
exposed:              True
exposed-modules:      Conversion.ByteString
import-dirs:          /usr/lib/ghc-8.10.5/site-local/conversion-bytestring-1.0.1
library-dirs:         /usr/lib/ghc-8.10.5/site-local/conversion-bytestring-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.5/conversion-bytestring-1.0.1

hs-libraries:         HSconversion-bytestring-1.0.1-h5IWBGzHid7H9R6NI1Axd
depends:
    base-prelude-1.4-6gvPEnwZlZz39pkAigtkjO bytestring-0.10.12.0
    conversion-1.2.1-JnVVyS6dR55LvEhMExxxl5

haddock-interfaces:
    /usr/share/doc/haskell-conversion-bytestring/html/conversion-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-conversion-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conversion-bytestring-1.0.1-19-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conversion-bytestring.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 conversion-bytestring
version:              1.0.1
visibility:           public
id:                   conversion-bytestring-1.0.1-9dX2lfu8Q3LK4zmmsRAI94
key:                  conversion-bytestring-1.0.1-9dX2lfu8Q3LK4zmmsRAI94
license:              MIT
copyright:            (c) 2015, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/conversion-bytestring 
synopsis:             "Conversion" instances for the "bytestring" library
category:             Control, Data, Conversion
abi:                  012d9fc5972b583c2394c41efdfbcc8b
exposed:              True
exposed-modules:      Conversion.ByteString
import-dirs:          /usr/lib/ghc-9.0.1/site-local/conversion-bytestring-1.0.1
library-dirs:         /usr/lib/ghc-9.0.1/site-local/conversion-bytestring-1.0.1
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-9.0.1/conversion-bytestring-1.0.1

hs-libraries:         HSconversion-bytestring-1.0.1-9dX2lfu8Q3LK4zmmsRAI94
depends:
    base-prelude-1.4-wnQZLjYbC0AMx10nDA4zk bytestring-0.10.12.1
    conversion-1.2.1-DY5ypJ3AebZGkeKm6ytgIp

haddock-interfaces:
    /usr/share/doc/haskell-conversion-bytestring/html/conversion-bytestring.haddock

haddock-html:         /usr/share/doc/haskell-conversion-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
